@@ -1,5 +1,5 @@
 /*
-    GNOME Commander - A GNOME based file manager 
+    GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
@@ -14,38 +14,39 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/ 
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
 
 #ifndef __GNOME_CMD_FILE_INFO_H__
 #define __GNOME_CMD_FILE_INFO_H__
 
+G_BEGIN_DECLS
 
 #define GNOME_CMD_FILE_INFO(obj) \
-	GTK_CHECK_CAST (obj, gnome_cmd_file_info_get_type (), GnomeCmdFileInfo)
+    GTK_CHECK_CAST (obj, gnome_cmd_file_info_get_type (), GnomeCmdFileInfo)
 #define GNOME_CMD_FILE_INFO_CLASS(klass) \
-	GTK_CHECK_CLASS_CAST (klass, gnome_cmd_file_info_get_type (), GnomeCmdFileInfoClass)
+    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_file_info_get_type (), GnomeCmdFileInfoClass)
 #define GNOME_CMD_IS_FILE_INFO(obj) \
     GTK_CHECK_TYPE (obj, gnome_cmd_file_info_get_type ())
 
 
 typedef struct _GnomeCmdFileInfo GnomeCmdFileInfo;
 typedef struct _GnomeCmdFileInfoClass GnomeCmdFileInfoClass;
-typedef struct _GnomeCmdFileInfoPrivate	GnomeCmdFileInfoPrivate;
+typedef struct _GnomeCmdFileInfoPrivate    GnomeCmdFileInfoPrivate;
 
 struct _GnomeCmdFileInfo
 {
-	GtkObject parent;
+    GtkObject parent;
 
-	GnomeVFSURI *uri;
-	GnomeVFSFileInfo *info;
-	
-	GnomeCmdFileInfoPrivate *priv;
+    GnomeVFSURI *uri;
+    GnomeVFSFileInfo *info;
+
+    GnomeCmdFileInfoPrivate *priv;
 };
 
 struct _GnomeCmdFileInfoClass
 {
-	GtkObjectClass parent_class;
+    GtkObjectClass parent_class;
 };
 
 
@@ -54,7 +55,9 @@ gnome_cmd_file_info_get_type (void);
 
 void
 gnome_cmd_file_info_setup (GnomeCmdFileInfo *finfo,
-						   GnomeVFSURI *uri,
-						   GnomeVFSFileInfo *info);
+                           GnomeVFSURI *uri,
+                           GnomeVFSFileInfo *info);
+
+G_END_DECLS
 
 #endif //__GNOME_CMD_FILE_INFO_H__
