@@ -14,12 +14,12 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
+
 #ifndef __LIBGCMD_DEPS_H__
 #define __LIBGCMD_DEPS_H__
 
-
 #include <gdk/gdk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
@@ -29,7 +29,10 @@
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 
+G_BEGIN_DECLS
+
 extern GtkWidget *main_win_widget;
 
+G_END_DECLS
 
 #endif //__LIBGCMD_DEPS_H__
