@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __CAP_H__
@@ -23,9 +23,12 @@
 #include "gnome-cmd-file-list.h"
 #include "gnome-cmd-dir.h"
 
+G_BEGIN_DECLS
+
 void cap_cut_files (GnomeCmdFileList *fl, GList *files);
 void cap_copy_files (GnomeCmdFileList *fl, GList *files);
 void cap_paste_files (GnomeCmdDir *dir);
 
+G_END_DECLS
 
 #endif // __CAP_H__
