@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __FILTER_H__
@@ -22,6 +22,8 @@
 
 #include <regex.h>
 
+G_BEGIN_DECLS
+
 typedef enum {
     FILTER_TYPE_REGEX,
     FILTER_TYPE_FNMATCH
@@ -51,5 +53,6 @@ void     filter_free  (Filter *filter);
 gboolean filter_match (Filter *filter,
                        gchar *text);
 
+G_END_DECLS
 
-#endif //__FILTER_H__
+#endif // __FILTER_H__
