@@ -14,11 +14,12 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #ifndef __GNOME_CMD_CMDLINE_H__
 #define __GNOME_CMD_CMDLINE_H__
 
+G_BEGIN_DECLS
 
 #define GNOME_CMD_CMDLINE(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_cmdline_get_type (), GnomeCmdCmdline)
@@ -33,7 +34,6 @@ typedef struct _GnomeCmdCmdlinePrivate GnomeCmdCmdlinePrivate;
 typedef struct _GnomeCmdCmdlineClass GnomeCmdCmdlineClass;
 
 
-
 struct _GnomeCmdCmdline
 {
     GtkHBox parent;
@@ -93,4 +93,6 @@ gboolean
 gnome_cmd_cmdline_keypressed   (GnomeCmdCmdline *cmdline,
                                 GdkEventKey *event);
 
-#endif //__GNOME_CMD_CMDLINE_H__
+G_END_DECLS
+
+#endif // __GNOME_CMD_CMDLINE_H__
