@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -59,8 +59,8 @@ struct _GnomeCmdDataPrivate
     gint                 main_win_width, main_win_height;
     gboolean             case_sens_sort;
     gboolean             confirm_delete;
-	GnomeCmdConfirmOverwriteMode confirm_copy_overwrite;
-	GnomeCmdConfirmOverwriteMode confirm_move_overwrite;
+    GnomeCmdConfirmOverwriteMode confirm_copy_overwrite;
+    GnomeCmdConfirmOverwriteMode confirm_move_overwrite;
     gint                 list_row_height;
     gchar                *list_font;
     GnomeCmdRightMouseButtonMode right_mouse_button_mode;
@@ -83,7 +83,7 @@ struct _GnomeCmdDataPrivate
     gint                 quick_connect_port;
     gboolean             honor_expect_uris;
     gboolean             use_internal_viewer;
-    gboolean             alt_quick_search ;
+    gboolean             alt_quick_search;
     gboolean             skip_mounting;
     gboolean             toolbar_visibility;
     gboolean             buttonbar_visibility;
@@ -101,6 +101,8 @@ struct _GnomeCmdDataPrivate
     gint                 main_win_pos[2];
     gchar                *backup_pattern;
     GList                *backup_pattern_list;
+    GdkWindowState       main_win_state;
+    gchar                *symlink_prefix;
 
     gchar *viewer;
     gchar *editor;
@@ -118,38 +120,42 @@ static gint get_int (const gchar *path, int def)
 }
 
 
-static void write_ftp_servers ()
+static void write_ftp_servers (const gchar *fname)
 {
-    gchar *path;
-    FILE *fd;
+    gchar *path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir(), fname);
+    FILE  *fd = fopen (path, "w");
+
+    if (fd != NULL)
+    {
+        GList *tmp;
 
-    path = g_strdup_printf ("%s/.gnome-commander/ftp-servers", g_get_home_dir());
-    fd = fopen (path, "w");
-    if (fd != NULL) {
-        GList *tmp = gnome_cmd_con_list_get_all_ftp (data->priv->con_list);
         chmod (path, S_IRUSR|S_IWUSR);
-        while (tmp) {
+
+        for (tmp = gnome_cmd_con_list_get_all_ftp (data->priv->con_list); tmp; tmp = tmp->next)
+        {
             GnomeCmdConFtp *server = GNOME_CMD_CON_FTP (tmp->data);
-            if (server) {
+
+            if (server)
+            {
                 gchar *alias = gnome_vfs_escape_string (gnome_cmd_con_ftp_get_alias (server));
                 gchar *hname = gnome_vfs_escape_string (gnome_cmd_con_ftp_get_host_name (server));
+                gushort port = gnome_cmd_con_ftp_get_host_port (server);
+                gchar *remote_dir = gnome_vfs_escape_string (gnome_cmd_con_ftp_get_remote_dir (server));
                 gchar *uname = gnome_vfs_escape_string (gnome_cmd_con_ftp_get_user_name (server));
                 gchar *pw    = gnome_vfs_escape_string (gnome_cmd_con_ftp_get_pw (server));
-                gushort port = gnome_cmd_con_ftp_get_host_port (server);
                 GnomeCmdBookmarkGroup *bookmark_group = gnome_cmd_con_get_bookmarks (GNOME_CMD_CON (server));
-                GList *bookmarks = bookmark_group->bookmarks;
+                GList *bookmarks;
 
-                if (pw)
-                    fprintf (fd, "S: %s %s %d %s %s\n", alias, hname, port, uname, pw);
-                else
-                    fprintf (fd, "S: %s %s %d %s\n", alias, hname, port, uname);
+                fprintf (fd, "C: %s %s %s %d %s %s %s\n", "ftp:", alias, hname, port, remote_dir, uname, pw?:"");
 
                 g_free (alias);
                 g_free (hname);
+                g_free (remote_dir);
                 g_free (uname);
-                if (pw) g_free (pw);
+                g_free (pw);
 
-                while (bookmarks) {
+                for (bookmarks = bookmark_group->bookmarks; bookmarks; bookmarks = bookmarks->next)
+                {
                     GnomeCmdBookmark *bookmark = (GnomeCmdBookmark*)bookmarks->data;
                     gchar *name = gnome_vfs_escape_string (bookmark->name);
                     gchar *path = gnome_vfs_escape_string (bookmark->path);
@@ -158,10 +164,8 @@ static void write_ftp_servers ()
 
                     g_free (name);
                     g_free (path);
-                    bookmarks = bookmarks->next;
                 }
             }
-            tmp = tmp->next;
         }
 
         fclose (fd);
@@ -174,9 +178,9 @@ static void write_ftp_servers ()
 
 
 static void
-write_devices ()
+write_devices (const gchar *fname)
 {
-    gchar *path = g_strdup_printf ("%s/.gnome-commander/devices", g_get_home_dir());
+    gchar *path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir(), fname);
     FILE *fd = fopen (path, "w");
 
     if (fd != NULL) {
@@ -220,9 +224,9 @@ write_devices ()
 
 
 static void
-write_fav_apps ()
+write_fav_apps (const gchar *fname)
 {
-    gchar *path = g_strdup_printf ("%s/.gnome-commander/fav-apps", g_get_home_dir());
+    gchar *path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir(), fname);
     FILE *fd = fopen (path, "w");
 
     if (fd != NULL) {
@@ -261,68 +265,126 @@ write_fav_apps ()
 }
 
 
-static void load_ftp_servers ()
+static gboolean load_ftp_servers (const gchar *fname)
 {
-    gchar *path = g_strdup_printf ("%s/.gnome-commander/ftp-servers", g_get_home_dir());
-    FILE *fd = fopen (path, "r");
+    guint prev_ftp_cons_no = g_list_length(gnome_cmd_con_list_get_all_ftp(data->priv->con_list));
 
-    if (fd != NULL) {
-        gint ret=0;
-        GnomeCmdConFtp *server = NULL;
+    gchar *path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir(), fname);
+    FILE  *fd = fopen (path, "r");
 
-        do {
-            gchar line[1024];
+    if (fd)
+    {
+        gchar line[1024];
 
-            if (fgets (line, 1024, fd) != NULL) {
-                if (line[0] == 'S') {
-                    gchar alias[256], host[256], user[256], pw[256];
-                    gchar *alias2, *host2, *user2, *pw2=NULL;
-                    gint port;
+        while (fgets (line, sizeof(line), fd) != NULL)
+        {
+            GnomeCmdConFtp *server = NULL;
 
-                    ret = sscanf (line, "S: %s %s %d %s %s\n", alias, host, &port, user, pw);
-                    if (ret == 4 || ret == 5) {
-                        alias2 = gnome_vfs_unescape_string (alias, NULL);
-                        host2  = gnome_vfs_unescape_string (host, NULL);
-                        user2  = gnome_vfs_unescape_string (user, NULL);
-                        if (ret == 5)
-                            pw2 = gnome_vfs_unescape_string (pw, NULL);
+            switch (line[0])
+            {
+                case '\0':             // do not warn about empty lines
+                case '#' :             // do not warn about empty comments
+                    break;
 
-                        server = gnome_cmd_con_ftp_new (alias2, host2, (gshort)port, user2, pw2);
+                case 'S':
+                    {
+                        gchar alias[256], host[256], user[256], pw[256];
+                        gchar *alias2, *host2, *user2, *pw2=NULL;
+                        gint port;
 
-                        gnome_cmd_con_list_add_ftp (data->priv->con_list, server);
+                        gint ret = sscanf (line, "S: %256s %256s %d %256s %256s\n", alias, host, &port, user, pw);
 
-                        g_free (alias2);
-                        g_free (host2);
-                        g_free (user2);
-                        if (pw2) g_free (pw2);
+                        if (ret == 4 || ret == 5)
+                        {
+                            alias2 = gnome_vfs_unescape_string (alias, NULL);
+                            host2  = gnome_vfs_unescape_string (host, NULL);
+                            user2  = gnome_vfs_unescape_string (user, NULL);
+                            if (ret == 5)
+                                pw2 = gnome_vfs_unescape_string (pw, NULL);
+
+                            server = gnome_cmd_con_ftp_new (alias2, host2, (gshort)port, user2, pw2, "");
+
+                            gnome_cmd_con_list_add_ftp (data->priv->con_list, server);
+
+                            g_free (alias2);
+                            g_free (host2);
+                            g_free (user2);
+                            g_free (pw2);
+                        }
                     }
-                }
-                else if (line[0] == 'B' && server) {
-                    gchar name[256], path[256];
-                    ret = sscanf (line, "B: %s %s\n", name, path);
-                    if (ret == 2) {
-                        GnomeCmdBookmarkGroup *group = gnome_cmd_con_get_bookmarks (GNOME_CMD_CON (server));
-                        GnomeCmdBookmark *bookmark = g_new (GnomeCmdBookmark, 1);
-                        bookmark->name = gnome_vfs_unescape_string (name, NULL);
-                        bookmark->path = gnome_vfs_unescape_string (path, NULL);
-                        bookmark->group = group;
+                    break;
 
-                        group->bookmarks = g_list_append (group->bookmarks, bookmark);
+                case 'C':
+                    {
+                        gchar **a = g_strsplit_set(line, " \t\n", 9);
+                        gint port2;
+
+                        if (g_strv_length(a)==9             &&
+                            strcmp(a[0], "C:")==0           &&
+                            strcmp(a[1], "ftp:")==0         &&
+                            sscanf(a[4], "%ud", &port2)==1)
+                        {
+                            gchar *alias2       = gnome_vfs_unescape_string (a[2], NULL);
+                            gchar *host2        = gnome_vfs_unescape_string (a[3], NULL);
+                            gchar *remote_dir2  = gnome_vfs_unescape_string (a[5], NULL);
+                            gchar *user2        = gnome_vfs_unescape_string (a[6], NULL);
+                            gchar *pw2          = gnome_vfs_unescape_string (a[7], NULL);
+
+                            GnomeCmdConFtp *server = gnome_cmd_con_ftp_new (alias2, host2, (gshort)port2, user2, pw2, remote_dir2);
+
+                            g_free (alias2);
+                            g_free (host2);
+                            g_free (remote_dir2);
+                            g_free (user2);
+                            g_free (pw2);
+
+                            gnome_cmd_con_list_add_ftp (data->priv->con_list, server);
+                        }
+                        else
+                        {
+                            g_warning ("Invalid line in the '%s' file - skipping it...", path);
+                            g_warning ("\t... %s", line);
+                        }
+
+                        g_strfreev(a);
                     }
-                }
-                else
-                    g_warning ("Invalid line in the ftp-servers file - skipping it...\n");
+                    break;
+
+                case 'B':
+                    if (server)
+                    {
+                        gchar name[256], path[256];
+                        gint ret = sscanf (line, "B: %256s %256s\n", name, path);
+
+                        if (ret == 2)
+                        {
+                            GnomeCmdBookmarkGroup *group = gnome_cmd_con_get_bookmarks (GNOME_CMD_CON (server));
+                            GnomeCmdBookmark *bookmark = g_new0 (GnomeCmdBookmark, 1);
+                            bookmark->name = gnome_vfs_unescape_string (name, NULL);
+                            bookmark->path = gnome_vfs_unescape_string (path, NULL);
+                            bookmark->group = group;
+
+                            group->bookmarks = g_list_append (group->bookmarks, bookmark);
+                        }
+                    }
+                    break;
+
+                default:
+                    g_warning ("Invalid line in the '%s' file - skipping it...", path);
+                    g_warning ("\t... %s", line);
+                    break;
             }
-            else
-                break;
-        } while (1);
+        }
 
         fclose (fd);
     }
-    else if (errno != ENOENT)
-        warn_print ("Failed to open the file %s for reading\n", path);
+    else
+        if (errno != ENOENT)
+            warn_print ("Failed to open the file %s for reading\n", path);
 
     g_free (path);
+
+    return fd!=NULL && g_list_length(gnome_cmd_con_list_get_all_ftp(data->priv->con_list))>prev_ftp_cons_no;
 }
 
 
@@ -338,12 +400,12 @@ vfs_is_uri_local(const char* uri)
 
     b = gnome_vfs_uri_is_local(pURI);
     gnome_vfs_uri_unref(pURI);
-    
+
     /* make sure this is actually a local path
            (gnome treats "burn://" as local, too and we don't want that)  */
     if (g_strncasecmp(uri,"file:/", 6)!=0)
-	    b = FALSE ;
-    
+        b = FALSE;
+
     DEBUG('m',"uri (%s) is %slocal\n", uri, b?"":"NOT ");
 
     return b;
@@ -380,7 +442,7 @@ remove_vfs_volume (GnomeVFSVolume *volume)
                 DEBUG('m',"Remove Volume:\ndevice_fn = %s\tmountp = %s\n",
                 device_fn,mountp);
                 gnome_cmd_con_list_remove_device(data->priv->con_list, device);
-		break;
+                break;
             }
         }
     }
@@ -390,32 +452,34 @@ remove_vfs_volume (GnomeVFSVolume *volume)
     g_free (localpath);
 }
 
+
 static gboolean
 device_mount_point_exists(GnomeCmdConList *list, const gchar* mountpoint)
 {
-	gboolean rc = FALSE ;
-	GList *tmp;
+    gboolean rc = FALSE;
+    GList *tmp;
 
-	for (tmp = gnome_cmd_con_list_get_all_dev (list); tmp != NULL; tmp = tmp->next) {
-	    GnomeCmdConDevice *device = GNOME_CMD_CON_DEVICE (tmp->data);
-	    if (device &&
-		!gnome_cmd_con_device_get_autovol(device)) {
-		gchar *mountp = gnome_vfs_escape_string (gnome_cmd_con_device_get_mountp (device));
-		gchar *mountp2= gnome_vfs_unescape_string (mountp, NULL);
+    for (tmp = gnome_cmd_con_list_get_all_dev (list); tmp != NULL; tmp = tmp->next) {
+        GnomeCmdConDevice *device = GNOME_CMD_CON_DEVICE (tmp->data);
+        if (device &&
+        !gnome_cmd_con_device_get_autovol(device)) {
+        gchar *mountp = gnome_vfs_escape_string (gnome_cmd_con_device_get_mountp (device));
+        gchar *mountp2= gnome_vfs_unescape_string (mountp, NULL);
 
-		if (strcmp(mountp2, mountpoint)==0)
-			rc = TRUE ;
-		
-		g_free (mountp);
-		g_free (mountp2);
-		
-		if (rc)
-			break;
-	    }
-	}
-	return rc ;
+        if (strcmp(mountp2, mountpoint)==0)
+            rc = TRUE;
+
+        g_free (mountp);
+        g_free (mountp2);
+
+        if (rc)
+            break;
+        }
+    }
+    return rc;
 }
 
+
 static void
 add_vfs_volume (GnomeVFSVolume *volume)
 {
@@ -423,8 +487,8 @@ add_vfs_volume (GnomeVFSVolume *volume)
     GnomeVFSDrive *drive;
     GnomeCmdConDevice *ConDev;
     GtkIconInfo *iconinfo;
-    GtkIconTheme *icontheme ;
-	
+    GtkIconTheme *icontheme;
+
     if (!gnome_vfs_volume_is_user_visible (volume))
         return;
 
@@ -439,36 +503,36 @@ add_vfs_volume (GnomeVFSVolume *volume)
     icon = gnome_vfs_volume_get_icon (volume);
     name = gnome_vfs_volume_get_display_name (volume);
     drive = gnome_vfs_volume_get_drive (volume);
-    
+
     /* Try to load the icon, using current theme */
-    iconpath = NULL ;
-    icontheme = gtk_icon_theme_get_default() ;
+    iconpath = NULL;
+    icontheme = gtk_icon_theme_get_default();
     if (icontheme) {
-	    iconinfo = gtk_icon_theme_lookup_icon (icontheme,icon,16,0) ;
-	    if (iconinfo) {
-		/* This returned string should not be free, see gtk documentation */
-		iconpath = gtk_icon_info_get_filename (iconinfo);
-	    }
+        iconinfo = gtk_icon_theme_lookup_icon (icontheme,icon,16,0);
+        if (iconinfo) {
+        /* This returned string should not be free, see gtk documentation */
+        iconpath = gtk_icon_info_get_filename (iconinfo);
+        }
     }
 
 
     localpath = gnome_vfs_get_local_path_from_uri (uri);
 
-    DEBUG('m',"name = %s\n", name) ;
-    DEBUG('m',"path = %s\n", path ) ;
-    DEBUG('m',"uri = %s\n", uri) ;
-    DEBUG('m',"local = %s\n", localpath) ;
-    DEBUG('m',"icon = %s (full path = %s)\n", icon, iconpath) ;
+    DEBUG('m',"name = %s\n", name);
+    DEBUG('m',"path = %s\n", path );
+    DEBUG('m',"uri = %s\n", uri);
+    DEBUG('m',"local = %s\n", localpath);
+    DEBUG('m',"icon = %s (full path = %s)\n", icon, iconpath);
 
     /* Don't create a new device connect if one already exists.
                 This can happen if the user manually added the same device in "Options|Devices" menu */
     if (!device_mount_point_exists(data->priv->con_list, localpath)) {
-	ConDev = gnome_cmd_con_device_new (name, path?path:NULL, localpath, iconpath);
-	gnome_cmd_con_device_set_autovol(ConDev, TRUE);
-	gnome_cmd_con_device_set_vfs_volume(ConDev, volume);
-	gnome_cmd_con_list_add_device (data->priv->con_list,ConDev);
+    ConDev = gnome_cmd_con_device_new (name, path?path:NULL, localpath, iconpath);
+    gnome_cmd_con_device_set_autovol(ConDev, TRUE);
+    gnome_cmd_con_device_set_vfs_volume(ConDev, volume);
+    gnome_cmd_con_list_add_device (data->priv->con_list,ConDev);
     } else {
-	DEBUG('m', "Device for mountpoint(%s) already exists. AutoVolume not added\n", localpath);
+    DEBUG('m', "Device for mountpoint(%s) already exists. AutoVolume not added\n", localpath);
     }
 
     g_free (path);
@@ -476,7 +540,7 @@ add_vfs_volume (GnomeVFSVolume *volume)
     g_free (icon);
     g_free (name);
     g_free (localpath);
-    
+
     gnome_vfs_drive_unref (drive);
 }
 
@@ -559,15 +623,11 @@ set_vfs_volume_monitor()
 {
       monitor = gnome_vfs_get_volume_monitor ();
 
-    g_signal_connect (monitor, "volume_mounted",
-        G_CALLBACK (volume_mounted), NULL);
-    g_signal_connect (monitor, "volume_unmounted",
-        G_CALLBACK (volume_unmounted), NULL);
+    g_signal_connect (monitor, "volume_mounted", G_CALLBACK (volume_mounted), NULL);
+    g_signal_connect (monitor, "volume_unmounted", G_CALLBACK (volume_unmounted), NULL);
 #if 0
-    g_signal_connect (monitor, "drive_connected",
-        G_CALLBACK (drive_connected), NULL);
-    g_signal_connect (monitor, "drive_disconnected",
-        G_CALLBACK (drive_disconnected), NULL);
+    g_signal_connect (monitor, "drive_connected", G_CALLBACK (drive_connected), NULL);
+    g_signal_connect (monitor, "drive_disconnected", G_CALLBACK (drive_disconnected), NULL);
 #endif
 }
 
@@ -600,9 +660,9 @@ load_vfs_auto_devices()
 
 
 static void
-load_devices ()
+load_devices (const gchar *fname)
 {
-    gchar *path = g_strdup_printf ("%s/.gnome-commander/devices", g_get_home_dir());
+    gchar *path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir(), fname);
     FILE *fd = fopen (path, "r");
 
     if (fd != NULL) {
@@ -647,13 +707,13 @@ load_devices ()
 
 
 static void
-load_fav_apps ()
+load_fav_apps (const gchar *fname)
 {
     gchar *path;
     FILE *fd;
 
     data->priv->fav_apps = NULL;
-    path = g_strdup_printf ("%s/.gnome-commander/fav-apps", g_get_home_dir());
+    path = g_strdup_printf ("%s/.gnome-commander/%s", g_get_home_dir(), fname);
     fd = fopen (path, "r");
     if (fd != NULL) {
         int ret;
@@ -1033,26 +1093,19 @@ gnome_cmd_data_free                      (void)
             gtk_object_unref (GTK_OBJECT (data->priv->con_list));
 
             /* free the anonymous password string */
-            if (data->priv->ftp_anonymous_password)
-                g_free (data->priv->ftp_anonymous_password);
+            g_free (data->priv->ftp_anonymous_password);
 
             /* free the dateformat string */
-            if (data->priv->date_format)
-                g_free (data->priv->date_format);
+            g_free (data->priv->date_format);
 
             /* free the font name strings */
-            if (data->priv->list_font)
-                g_free (data->priv->list_font);
+            g_free (data->priv->list_font);
 
             /* free the external programs strings */
-            if (data->priv->viewer)
-                g_free (data->priv->viewer);
-            if (data->priv->editor)
-                g_free (data->priv->editor);
-            if (data->priv->differ)
-                g_free (data->priv->differ);
-            if (data->priv->term)
-                g_free (data->priv->term);
+            g_free (data->priv->viewer);
+            g_free (data->priv->editor);
+            g_free (data->priv->differ);
+            g_free (data->priv->term);
 
             g_free (data->priv);
         }
@@ -1081,8 +1134,8 @@ gnome_cmd_data_save                      (void)
     gnome_cmd_data_set_int    ("/options/list_row_height", data->priv->list_row_height);
 
     gnome_cmd_data_set_bool   ("/confirm/delete", data->priv->confirm_delete);
-	gnome_cmd_data_set_int    ("/confirm/copy_overwrite", data->priv->confirm_copy_overwrite);
-	gnome_cmd_data_set_int    ("/confirm/move_overwrite", data->priv->confirm_move_overwrite);
+    gnome_cmd_data_set_int    ("/confirm/copy_overwrite", data->priv->confirm_copy_overwrite);
+    gnome_cmd_data_set_int    ("/confirm/move_overwrite", data->priv->confirm_move_overwrite);
 
     gnome_cmd_data_set_bool   ("/options/show_unknown", data->priv->filter_settings.file_types[GNOME_VFS_FILE_TYPE_UNKNOWN]);
     gnome_cmd_data_set_bool   ("/options/show_regular", data->priv->filter_settings.file_types[GNOME_VFS_FILE_TYPE_REGULAR]);
@@ -1130,6 +1183,11 @@ gnome_cmd_data_save                      (void)
     gnome_cmd_data_set_bool   ("/programs/toolbar_visibility", data->priv->toolbar_visibility);
     gnome_cmd_data_set_bool   ("/programs/buttonbar_visibility", data->priv->buttonbar_visibility);
 
+    if (data->priv->symlink_prefix && *data->priv->symlink_prefix && strcmp(data->priv->symlink_prefix,_("link to %s"))!=0)
+        gnome_cmd_data_set_string ("/options/symlink_prefix", data->priv->symlink_prefix);
+    else
+        gnome_cmd_data_set_string ("/options/symlink_prefix", "");
+
     gnome_cmd_data_set_int    ("/options/main_win_pos_x", data->priv->main_win_pos[0]);
     gnome_cmd_data_set_int    ("/options/main_win_pos_y", data->priv->main_win_pos[1]);
 
@@ -1165,12 +1223,14 @@ gnome_cmd_data_save                      (void)
     gnome_cmd_data_set_string ("/defaults/last_pattern", data->priv->last_pattern);
     gnome_cmd_data_set_string ("/defaults/backup_pattern", data->priv->backup_pattern);
 
+    gnome_cmd_data_set_int ("/options/main_win_state",(gint) data->priv->main_win_state);
+
     write_cmdline_history ();
     //write_dir_history ();
 
-    write_ftp_servers ();
-    write_devices ();
-    write_fav_apps ();
+    write_ftp_servers ("connections");
+    write_devices ("devices");
+    write_fav_apps ("fav-apps");
     write_search_defaults ();
     write_rename_history ();
     write_local_bookmarks ();
@@ -1223,6 +1283,14 @@ gnome_cmd_data_load                      (void)
     data->priv->color_themes[GNOME_CMD_COLOR_CLASSIC].curs_fg = gdk_color_new (0,0,0);
     data->priv->color_themes[GNOME_CMD_COLOR_CLASSIC].curs_bg = gdk_color_new (0xaaaa,0xaaaa,0xaaaa);
 
+    data->priv->color_themes[GNOME_CMD_COLOR_DEEP_BLUE].respect_theme = FALSE;
+    data->priv->color_themes[GNOME_CMD_COLOR_DEEP_BLUE].norm_fg = gdk_color_new (0,65535,65535);
+    data->priv->color_themes[GNOME_CMD_COLOR_DEEP_BLUE].norm_bg = gdk_color_new (0,0,32896);
+    data->priv->color_themes[GNOME_CMD_COLOR_DEEP_BLUE].sel_fg = gdk_color_new (65535,65535,0);
+    data->priv->color_themes[GNOME_CMD_COLOR_DEEP_BLUE].sel_bg = gdk_color_new (32896,32896,32896);
+    data->priv->color_themes[GNOME_CMD_COLOR_DEEP_BLUE].curs_fg = gdk_color_new (0,0,0);
+    data->priv->color_themes[GNOME_CMD_COLOR_DEEP_BLUE].curs_bg = gdk_color_new (43690,43690,43690);
+
     data->priv->color_themes[GNOME_CMD_COLOR_NONE].respect_theme = TRUE;
     data->priv->color_themes[GNOME_CMD_COLOR_NONE].norm_fg = NULL;
     data->priv->color_themes[GNOME_CMD_COLOR_NONE].norm_bg = NULL;
@@ -1250,7 +1318,7 @@ gnome_cmd_data_load                      (void)
     data->priv->confirm_copy_overwrite = gnome_cmd_data_get_int ("/confirm/copy_overwrite", GNOME_CMD_CONFIRM_OVERWRITE_QUERY);
     data->priv->confirm_move_overwrite = gnome_cmd_data_get_int ("/confirm/move_overwrite", GNOME_CMD_CONFIRM_OVERWRITE_QUERY);
 
-	data->priv->filter_settings.file_types[GNOME_VFS_FILE_TYPE_UNKNOWN] =
+    data->priv->filter_settings.file_types[GNOME_VFS_FILE_TYPE_UNKNOWN] =
         gnome_cmd_data_get_bool ("/options/show_unknown", FALSE);
 
     data->priv->filter_settings.file_types[GNOME_VFS_FILE_TYPE_REGULAR] =
@@ -1294,7 +1362,7 @@ gnome_cmd_data_load                      (void)
         g_free (tmp);
     }
 
-    data->priv->color_mode = gnome_cmd_data_get_int ("/colors/mode", GNOME_CMD_COLOR_CLASSIC);
+    data->priv->color_mode = gnome_cmd_data_get_int ("/colors/mode", GNOME_CMD_COLOR_DEEP_BLUE);
 
     gnome_cmd_data_get_color ("/colors/norm_fg", data->priv->color_themes[GNOME_CMD_COLOR_CUSTOM].norm_fg);
     gnome_cmd_data_get_color ("/colors/norm_bg", data->priv->color_themes[GNOME_CMD_COLOR_CUSTOM].norm_bg);
@@ -1336,6 +1404,13 @@ gnome_cmd_data_load                      (void)
     data->priv->toolbar_visibility = gnome_cmd_data_get_bool ("/programs/toolbar_visibility", TRUE);
     data->priv->buttonbar_visibility = gnome_cmd_data_get_bool ("/programs/buttonbar_visibility", TRUE);
 
+    data->priv->symlink_prefix = gnome_cmd_data_get_string ("/options/symlink_prefix", _("link to %s"));
+    if (!*data->priv->symlink_prefix || strcmp(data->priv->symlink_prefix, _("link to %s"))==0)
+    {
+        g_free(data->priv->symlink_prefix);
+        data->priv->symlink_prefix = NULL;
+    }
+    
     data->priv->sort_column[LEFT] = gnome_cmd_data_get_int ("/options/sort_column_left", FILE_LIST_COLUMN_NAME);
     data->priv->sort_direction[LEFT] = gnome_cmd_data_get_bool ( "/options/sort_direction_left", FILE_LIST_SORT_ASCENDING);
     data->priv->sort_column[RIGHT] = gnome_cmd_data_get_int ("/options/sort_column_right", FILE_LIST_COLUMN_NAME);
@@ -1361,6 +1436,8 @@ gnome_cmd_data_load                      (void)
     data->priv->quick_connect_port = gnome_cmd_data_get_int    ("/quick-connect/port", 21);
     data->priv->quick_connect_user = gnome_cmd_data_get_string ("/quick-connect/user", "anonymous");
 
+    data->priv->main_win_state = gnome_cmd_data_get_int ("/options/main_win_state", (gint) GDK_WINDOW_STATE_MAXIMIZED);
+
     load_cmdline_history ();
     //load_dir_history ();
     load_search_defaults ();
@@ -1376,11 +1453,11 @@ gnome_cmd_data_load_more (void)
 {
     data->priv->con_list = gnome_cmd_con_list_new ();
     gnome_cmd_con_list_begin_update (data->priv->con_list);
-    load_devices ();
-    load_ftp_servers ();
+    load_devices ("devices");
+    load_ftp_servers ("connections") || load_ftp_servers ("ftp-servers");
     gnome_cmd_con_list_end_update (data->priv->con_list);
 
-    load_fav_apps ();
+    load_fav_apps ("fav-apps");
     load_local_bookmarks ();
     load_smb_bookmarks ();
 }
@@ -1434,6 +1511,7 @@ gnome_cmd_data_get_fav_apps               (void)
     return data->priv->fav_apps;
 }
 
+
 void
 gnome_cmd_data_set_fav_apps               (GList *apps)
 {
@@ -1667,28 +1745,28 @@ gnome_cmd_data_set_confirm_delete       (gboolean value)
 GnomeCmdConfirmOverwriteMode
 gnome_cmd_data_get_confirm_overwrite_copy(void)
 {
-	return data->priv->confirm_copy_overwrite;
+    return data->priv->confirm_copy_overwrite;
 }
 
 
 void
 gnome_cmd_data_set_confirm_overwrite_copy(GnomeCmdConfirmOverwriteMode value)
 {
-	data->priv->confirm_copy_overwrite = value;
+    data->priv->confirm_copy_overwrite = value;
 }
 
 
 GnomeCmdConfirmOverwriteMode
 gnome_cmd_data_get_confirm_overwrite_move(void)
 {
-	return data->priv->confirm_move_overwrite;
+    return data->priv->confirm_move_overwrite;
 }
 
 
 void
 gnome_cmd_data_set_confirm_overwrite_move(GnomeCmdConfirmOverwriteMode value)
 {
-	data->priv->confirm_move_overwrite = value;
+    data->priv->confirm_move_overwrite = value;
 }
 
 
@@ -1893,6 +1971,13 @@ gnome_cmd_data_get_type_filter (GnomeVFSFileType type)
 }
 
 
+void
+gnome_cmd_data_set_hidden_filter (gboolean hide)
+{
+    data->priv->filter_settings.hidden = hide;
+}
+
+
 gboolean
 gnome_cmd_data_get_hidden_filter (void)
 {
@@ -2055,6 +2140,7 @@ gnome_cmd_data_set_alt_quick_search (gboolean value)
     data->priv->alt_quick_search = value;
 }
 
+
 gboolean
 gnome_cmd_data_get_skip_mounting (void)
 {
@@ -2201,13 +2287,13 @@ gnome_cmd_data_get_gui_update_rate (void)
 void
 gnome_cmd_data_get_sort_params (GnomeCmdFileList *fl, gint *col, gboolean *direction)
 {
-    if (!gnome_cmd_main_win_get_left_fs (main_win) ||
-        gnome_cmd_main_win_get_left_fs (main_win)->list == fl) {
+    if (!gnome_cmd_main_win_get_fs (main_win, LEFT) ||
+        gnome_cmd_main_win_get_fs (main_win, LEFT)->list == fl) {
         *col = data->priv->sort_column[LEFT];
         *direction = data->priv->sort_direction[LEFT];
     }
-    else if (!gnome_cmd_main_win_get_right_fs (main_win) ||
-             gnome_cmd_main_win_get_right_fs (main_win)->list == fl) {
+    else if (!gnome_cmd_main_win_get_fs (main_win, RIGHT) ||
+             gnome_cmd_main_win_get_fs (main_win, RIGHT)->list == fl) {
         *col = data->priv->sort_column[RIGHT];
         *direction = data->priv->sort_direction[RIGHT];
     }
@@ -2217,11 +2303,11 @@ gnome_cmd_data_get_sort_params (GnomeCmdFileList *fl, gint *col, gboolean *direc
 void
 gnome_cmd_data_set_sort_params (GnomeCmdFileList *fl, gint col, gboolean direction)
 {
-    if (gnome_cmd_main_win_get_left_fs (main_win)->list == fl) {
+    if (gnome_cmd_main_win_get_fs (main_win, LEFT)->list == fl) {
         data->priv->sort_column[LEFT] = col;
         data->priv->sort_direction[LEFT] = direction;
     }
-    else if (gnome_cmd_main_win_get_right_fs (main_win)->list == fl) {
+    else if (gnome_cmd_main_win_get_fs (main_win, RIGHT)->list == fl) {
         data->priv->sort_column[RIGHT] = col;
         data->priv->sort_direction[RIGHT] = direction;
     }
@@ -2271,3 +2357,29 @@ gnome_cmd_data_get_backup_pattern_list (void)
 {
     return data->priv->backup_pattern_list;
 }
+
+
+GdkWindowState gnome_cmd_data_get_main_win_state (void)
+{
+    return data->priv->main_win_state;
+}
+
+
+void gnome_cmd_data_set_main_win_state (GdkWindowState state)
+{
+    data->priv->main_win_state = state;
+//    data->priv->main_win_state = gdk_window_get_state (GTK_WIDGET (main_win)->window);
+}
+
+
+const gchar *gnome_cmd_data_get_symlink_prefix (void)
+{
+    return data->priv->symlink_prefix ? data->priv->symlink_prefix : _("link to %s");
+}
+
+
+void gnome_cmd_data_set_symlink_prefix (const gchar *value)
+{
+    data->priv->symlink_prefix = g_strdup (value);
+}
+
