@@ -14,15 +14,16 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #ifndef __GNOME_CMD_PREPARE_DEL_DIALOG_H__
 #define __GNOME_CMD_PREPARE_DEL_DIALOG_H__
 
+G_BEGIN_DECLS
 
 void
 gnome_cmd_delete_dialog_show (GList *files);
 
-#endif //__GNOME_CMD_PREPARE_DEL_DIALOG_H__
-
+G_END_DECLS
 
+#endif // __GNOME_CMD_PREPARE_DEL_DIALOG_H__
