@@ -28,6 +28,7 @@
 #include "imageloader.h"
 #include "utils.h"
 
+
 struct _GnomeCmdDirIndicatorPrivate
 {
     GtkWidget *event_box;
@@ -51,16 +52,13 @@ static GtkFrameClass *parent_class = NULL;
 /*******************************
  * Gtk class implementation
  *******************************/
-
 static void
 destroy (GtkObject *object)
 {
     GnomeCmdDirIndicator *dir_indicator = GNOME_CMD_DIR_INDICATOR (object);
 
-    if (dir_indicator->priv->slashCharPosition)
-        g_free (dir_indicator->priv->slashCharPosition);
-    if (dir_indicator->priv->slashPixelPosition)
-        g_free (dir_indicator->priv->slashPixelPosition);
+    g_free (dir_indicator->priv->slashCharPosition);
+    g_free (dir_indicator->priv->slashPixelPosition);
     g_free (dir_indicator->priv);
 
     if (GTK_OBJECT_CLASS (parent_class)->destroy)
@@ -71,11 +69,8 @@ destroy (GtkObject *object)
 static void
 class_init (GnomeCmdDirIndicatorClass *klass)
 {
-    GtkObjectClass *object_class;
-    GtkWidgetClass *widget_class;
-
-    object_class = GTK_OBJECT_CLASS (klass);
-    widget_class = GTK_WIDGET_CLASS (klass);
+    GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
+    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
     parent_class = gtk_type_class (gtk_frame_get_type ());
 
     object_class->destroy = destroy;
@@ -92,16 +87,17 @@ on_dir_indicator_clicked (GnomeCmdDirIndicator *indicator,
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR_INDICATOR (indicator), FALSE);
 
-    if (event->type == GDK_BUTTON_PRESS && event->button == 1) {
+    if (event->type == GDK_BUTTON_PRESS && event->button == 1)
+    {
         /* left click - work out the path */
-        gchar *chTo;
         const gchar *labelText = gtk_label_get_text (GTK_LABEL (indicator->priv->label));
-        chTo = g_strdup(labelText);
+        gchar *chTo = g_strdup(labelText);
         gint x = (gint)event->x;
         gint i;
 
-        for (i = 0; i < indicator->priv->numPositions; i++) {
-            if (x < indicator->priv->slashPixelPosition[i]) {
+        for (i = 0; i < indicator->priv->numPositions; i++)
+            if (x < indicator->priv->slashPixelPosition[i])
+            {
                 strncpy (chTo, labelText, indicator->priv->slashCharPosition[i]);
                 chTo[indicator->priv->slashCharPosition[i]] = 0x0;
                 gnome_cmd_main_win_switch_fs (main_win, fs);
@@ -109,11 +105,11 @@ on_dir_indicator_clicked (GnomeCmdDirIndicator *indicator,
                 g_free (chTo);
                 return TRUE;
             }
-        }
 
         /* pointer is after directory name - just return */
         return TRUE;
     }
+
     return FALSE;
 }
 
@@ -127,21 +123,21 @@ update_markup (GnomeCmdDirIndicator *indicator, gint i)
         return;
 
     s = g_strdup (gtk_label_get_text (GTK_LABEL (indicator->priv->label)));
-    if (i > 0) {
-        gchar *mt, *ms;
+    
+    if (i >= 0)
+    {
         gchar *t = g_strdup (&s[indicator->priv->slashCharPosition[i]]);
         s[indicator->priv->slashCharPosition[i]] = '\0';
 
-        mt = get_mono_text (t);
-        ms = get_bold_mono_text (s);
+        gchar *mt = get_mono_text (t);
+        gchar *ms = get_bold_mono_text (s);
         m = g_strdup_printf ("%s%s", ms, mt);
         g_free (t);
         g_free (mt);
         g_free (ms);
     }
-    else {
+    else
         m = get_mono_text (s);
-    }
 
     gtk_label_set_markup (GTK_LABEL (indicator->priv->label), m);
     g_free (s);
@@ -167,12 +163,12 @@ on_dir_indicator_motion (GnomeCmdDirIndicator *indicator,
     iX = (gint)event->x;
     iY = (gint)event->y;
 
-    for (i = 0; i < indicator->priv->numPositions; i++) {
-        if (iX < indicator->priv->slashPixelPosition[i]) {
+    for (i=0; i < indicator->priv->numPositions; i++)
+    {
+        if (iX < indicator->priv->slashPixelPosition[i])
+        {
             /* underline the part that is selected */
-            GdkCursor* cursor;
-
-            cursor = gdk_cursor_new(GDK_HAND2);
+            GdkCursor *cursor = gdk_cursor_new(GDK_HAND2);
             gdk_window_set_cursor(GTK_WIDGET(indicator)->window, cursor);
             gdk_cursor_destroy(cursor);
 
@@ -182,13 +178,14 @@ on_dir_indicator_motion (GnomeCmdDirIndicator *indicator,
         }
 
         /* clear underline, cursor=pointer */
-        update_markup (indicator, 0);
+        update_markup (indicator, -1);
         gdk_window_set_cursor(GTK_WIDGET (indicator)->window, NULL);
     }
 
     return TRUE;
 }
 
+
 static gint
 on_dir_indicator_leave (GnomeCmdDirIndicator *indicator,
                         GdkEventMotion *event,
@@ -197,31 +194,29 @@ on_dir_indicator_leave (GnomeCmdDirIndicator *indicator,
     g_return_val_if_fail (GNOME_CMD_IS_DIR_INDICATOR (indicator), FALSE);
 
     /* clear underline, cursor=pointer */
-    update_markup (indicator, 0);
+    update_markup (indicator, -1);
     gdk_window_set_cursor(GTK_WIDGET (indicator)->window, NULL);
 
     return TRUE;
 }
 
+
 static int
-getPixelSize (const char *s, int size)
+get_string_pixel_size (const char *s, int len)
 {
     /* find the size, in pixels, of the given string */
-    gchar *buf, *ms;
-    gchar *utf8buf;
     gint xSize, ySize;
-    GtkLabel *label;
-    PangoLayout *layout;
 
-    buf = g_strndup(s,size) ;
-    utf8buf = get_utf8 (buf);
+    gchar *buf = g_strndup(s, len);
+    gchar *utf8buf = get_utf8 (buf);
 
-    label = GTK_LABEL (gtk_label_new (utf8buf));
-    ms = get_mono_text (utf8buf);
+    GtkLabel *label = GTK_LABEL (gtk_label_new (utf8buf));
+    gchar *ms = get_mono_text (utf8buf);
     gtk_label_set_markup (label, ms);
     g_free (ms);
     g_object_ref (label);
-    layout = gtk_label_get_layout (label);
+
+    PangoLayout *layout = gtk_label_get_layout (label);
     pango_layout_get_pixel_size (layout, &xSize, &ySize);
 
     /* we're finished with the label */
@@ -236,11 +231,13 @@ getPixelSize (const char *s, int size)
 static gboolean
 on_bookmark_button_clicked (GtkWidget *button, GnomeCmdDirIndicator *indicator)
 {
-    if (indicator->priv->bookmark_is_popped) {
+    if (indicator->priv->bookmark_is_popped)
+    {
         gtk_widget_hide (indicator->priv->bookmark_popup);
         indicator->priv->bookmark_is_popped = FALSE;
     }
-    else {
+    else
+    {
         gnome_cmd_dir_indicator_show_bookmarks (indicator);
         indicator->priv->bookmark_is_popped = TRUE;
     }
@@ -252,11 +249,13 @@ on_bookmark_button_clicked (GtkWidget *button, GnomeCmdDirIndicator *indicator)
 static gboolean
 on_history_button_clicked (GtkWidget *button, GnomeCmdDirIndicator *indicator)
 {
-    if (indicator->priv->history_is_popped) {
+    if (indicator->priv->history_is_popped)
+    {
         gtk_widget_hide (indicator->priv->dir_history_popup);
         indicator->priv->history_is_popped = FALSE;
     }
-    else {
+    else
+    {
         gnome_cmd_dir_indicator_show_history (indicator);
         indicator->priv->history_is_popped = TRUE;
     }
@@ -312,11 +311,9 @@ get_popup_pos (GtkMenu *menu,
                gint *x, gint *y, gboolean push_in,
                GnomeCmdDirIndicator *indicator)
 {
-    GtkWidget *w;
-
     g_return_if_fail (GNOME_CMD_IS_DIR_INDICATOR (indicator));
 
-    w = GTK_WIDGET (indicator->priv->fs->list);
+    GtkWidget *w = GTK_WIDGET (indicator->priv->fs->list);
 
     gdk_window_get_origin (w->window, x, y);
 }
@@ -326,9 +323,7 @@ static void
 add_menu_item (GnomeCmdDirIndicator *indicator, GtkMenuShell *shell, const gchar *text,
                GtkSignalFunc func, gpointer data)
 {
-    GtkWidget *item;
-
-    item = text ? gtk_menu_item_new_with_label (text) : gtk_menu_item_new ();
+    GtkWidget *item = text ? gtk_menu_item_new_with_label (text) : gtk_menu_item_new ();
 
     gtk_widget_ref (item);
     gtk_object_set_data (GTK_OBJECT (item), "indicator", indicator);
@@ -364,7 +359,8 @@ popup_dir_history (GnomeCmdDirIndicator *indicator)
     con = gnome_cmd_file_selector_get_connection (indicator->priv->fs);
     history = gnome_cmd_con_get_dir_history (con);
 
-    for ( l = history->ents; l; l = l->next ) {
+    for (l=history->ents; l; l=l->next)
+    {
         gchar *path = (gchar*)l->data;
         add_menu_item (
             indicator,
@@ -379,7 +375,7 @@ popup_dir_history (GnomeCmdDirIndicator *indicator)
     if (GTK_WIDGET (indicator)->allocation.width > 100)
         w = GTK_WIDGET (indicator)->allocation.width;
 
-    gtk_widget_set_usize (indicator->priv->dir_history_popup, w, -1);
+    gtk_widget_set_size_request (indicator->priv->dir_history_popup, w, -1);
 }
 
 
@@ -390,7 +386,7 @@ on_bookmarks_add_current (GtkMenuItem *item, GnomeCmdDirIndicator *indicator)
     GnomeCmdCon *con = gnome_cmd_file_selector_get_connection (indicator->priv->fs);
     GnomeCmdBookmarkGroup *group = gnome_cmd_con_get_bookmarks (con);
 
-    GnomeCmdBookmark *bm = g_new (GnomeCmdBookmark, 1);
+    GnomeCmdBookmark *bm = g_new0 (GnomeCmdBookmark, 1);
 
     bm->name = g_strdup (gnome_cmd_file_get_name (GNOME_CMD_FILE (dir)));
     bm->path = gnome_cmd_file_get_path (GNOME_CMD_FILE (dir));
@@ -425,7 +421,8 @@ popup_bookmarks (GnomeCmdDirIndicator *indicator)
     con = gnome_cmd_file_selector_get_connection (indicator->priv->fs);
     group = gnome_cmd_con_get_bookmarks (con);
 
-    for ( l = group->bookmarks; l; l = l->next ) {
+    for (l = group->bookmarks; l; l = l->next)
+    {
         GnomeCmdBookmark *bm = (GnomeCmdBookmark*)l->data;
         add_menu_item (
             indicator,
@@ -444,7 +441,7 @@ popup_bookmarks (GnomeCmdDirIndicator *indicator)
     if (GTK_WIDGET (indicator)->allocation.width > 100)
         w = GTK_WIDGET (indicator)->allocation.width;
 
-    gtk_widget_set_usize (indicator->priv->bookmark_popup, w, -1);
+    gtk_widget_set_size_request (indicator->priv->bookmark_popup, w, -1);
 }
 
 
@@ -453,13 +450,14 @@ init (GnomeCmdDirIndicator *indicator)
 {
     GtkWidget *hbox, *arrow, *bbox;
 
-    indicator->priv = g_new (GnomeCmdDirIndicatorPrivate, 1);
-    indicator->priv->dir_history_popup = NULL;
-    indicator->priv->bookmark_popup = NULL;
-    indicator->priv->history_is_popped = FALSE;
-    indicator->priv->slashCharPosition = NULL;
-    indicator->priv->slashPixelPosition = NULL;
-    indicator->priv->numPositions = 0;
+    indicator->priv = g_new0 (GnomeCmdDirIndicatorPrivate, 1);
+    // below assignments are not necessary any longer due to above g_new0()
+    //  indicator->priv->dir_history_popup = NULL;
+    //  indicator->priv->bookmark_popup = NULL;
+    //  indicator->priv->history_is_popped = FALSE;
+    //  indicator->priv->slashCharPosition = NULL;
+    //  indicator->priv->slashPixelPosition = NULL;
+    //  indicator->priv->numPositions = 0;
 
     /* create the directory label and it's event box */
     indicator->priv->event_box = gtk_event_box_new ();
@@ -520,11 +518,12 @@ gnome_cmd_dir_indicator_get_type    (void)
 {
     static GtkType type = 0;
 
-    if (type == 0) {
+    if (type == 0)
+    {
         GtkTypeInfo info = {
             "GnomeCmdDirIndicator",
-            sizeof (GnomeCmdDirIndicator),
-            sizeof (GnomeCmdDirIndicatorClass),
+            sizeof(GnomeCmdDirIndicator),
+            sizeof(GnomeCmdDirIndicatorClass),
             (GtkClassInitFunc) class_init,
             (GtkObjectInitFunc) init,
             /* reserved_1 */ NULL,
@@ -544,11 +543,7 @@ gnome_cmd_dir_indicator_new (GnomeCmdFileSelector *fs)
 {
     GnomeCmdDirIndicator *dir_indicator = gtk_type_new (gnome_cmd_dir_indicator_get_type ());
 
-    gtk_signal_connect (
-        GTK_OBJECT (dir_indicator),
-        "button_press_event",
-        G_CALLBACK (on_dir_indicator_clicked),
-        fs);
+    gtk_signal_connect (GTK_OBJECT (dir_indicator), "button_press_event", G_CALLBACK (on_dir_indicator_clicked), fs);
 
     dir_indicator->priv->fs = fs;
 
@@ -559,64 +554,77 @@ gnome_cmd_dir_indicator_new (GnomeCmdFileSelector *fs)
 void
 gnome_cmd_dir_indicator_set_dir (GnomeCmdDirIndicator *indicator, const gchar *path)
 {
-    gint i;
-    gint numSlashes = 0;
     gchar *s = get_utf8 (path);
-
     gtk_label_set_text (GTK_LABEL (indicator->priv->label), s);
-    update_markup (indicator, 0);
+    update_markup (indicator, -1);
+    g_free (s);
 
-    /* Count the number of slashes in the string */
-    for (i = 0; i < strlen (path); i++) {
-        if (*(path + i) == '/')
-            numSlashes++;
-    }
+    g_free (indicator->priv->slashCharPosition);
+    g_free (indicator->priv->slashPixelPosition);
+    indicator->priv->numPositions = 0;
+    indicator->priv->slashCharPosition = NULL;
+    indicator->priv->slashPixelPosition = NULL;
 
-    /* there will now be numSlashes+1 entries */
-    /* first entry is just slash (root) */
-    /* 1..numSlashes-1 is /dir/dir etc. */
-    /* last entry will be whole string */
-    if (indicator->priv->slashCharPosition) {
-        g_free (indicator->priv->slashCharPosition);
-        indicator->priv->slashCharPosition = NULL ;
-    }
+    if (!path)
+        return;
 
-    if (indicator->priv->slashPixelPosition) {
-        g_free (indicator->priv->slashPixelPosition);
-        indicator->priv->slashPixelPosition = NULL ;
-    }
+    gboolean isUNC = g_str_has_prefix(path,"\\\\");
 
-    if (numSlashes > 0) {
-        /* if there are any slashes then allocate some memory
-           for storing their positions (both in char positions through
-           the string, and pixel positions on the display */
-        indicator->priv->slashCharPosition = g_malloc ((numSlashes + 1) * sizeof (int));
-        indicator->priv->slashPixelPosition = g_malloc ((numSlashes + 1) * sizeof (int));
-        indicator->priv->slashCharPosition[0] = 1;
-        indicator->priv->slashPixelPosition[0] = getPixelSize (path, 1);
-        numSlashes = 1;
+    if (!isUNC && *path!=G_DIR_SEPARATOR)
+        return;
 
-        for (i = 1; i < strlen (path); i++) {
-            if (*(path + i) == '/') {
-                /* underline everything up to but not including slash
-                 * but include the slash when calculating pixel size,
-                 * as /directory/ = /directory when doing chdir */
-                indicator->priv->slashCharPosition[numSlashes] = i;
-                indicator->priv->slashPixelPosition[numSlashes] = getPixelSize (path, i + 1);
-                numSlashes++;
-            }
+    const gchar sep = isUNC ? '\\' : G_DIR_SEPARATOR;
+    GArray *pos = g_array_sized_new (FALSE, FALSE, sizeof(gint), 16);
+    gint i;
+
+    for (s = isUNC ? path+2 : path+1; *s; ++s)
+        if (*s==sep)
+        {
+            i = s-path;
+            g_array_append_val (pos, i);
         }
 
-        /* make an entry that is the whole size of the path */
-        indicator->priv->slashCharPosition[numSlashes] = strlen (path);
-        indicator->priv->slashPixelPosition[numSlashes] = getPixelSize (path, strlen (path));
-        numSlashes++;
-        indicator->priv->numPositions = numSlashes;
-    }
-    else
-        indicator->priv->numPositions = 0;
+    gint path_len = s-path;
 
-    g_free (s);
+    // allocate memory for storing (back)slashes positions
+    // (both char positions within the string and their pixel positions in the display)
+
+    // now there will be pos->len entries for UNC:
+    //    [0..pos->len-2] is '\\host\share\dir' etc.
+    //    last entry [pos->len-1] will be the whole UNC
+    // pos->len+1 (1) entries for '/' (root):
+    //    last entry [pos->len] will be the whole path ('/')
+    // and pos->len+2 entries otherwise:
+    //    first entry [0] is just '/' (root)
+    //    [1..pos->len] is '/dir/dir' etc.
+    //    last entry [pos->len+1] will be the whole path
+
+    indicator->priv->numPositions = isUNC ? pos->len :
+                                    path_len==1 ? pos->len+1 : pos->len+2;
+    indicator->priv->slashCharPosition = g_new (gint, indicator->priv->numPositions);
+    indicator->priv->slashPixelPosition = g_new (gint, indicator->priv->numPositions);
+
+    gint pos_idx = 0;
+    
+    if (!isUNC && path_len>1)
+    {
+        indicator->priv->slashCharPosition[pos_idx] = 1;
+        indicator->priv->slashPixelPosition[pos_idx++] = get_string_pixel_size (path, 1);
+    }
+    
+    for (i = isUNC ? 1 : 0; i < pos->len; i++)
+    {
+        indicator->priv->slashCharPosition[pos_idx] = g_array_index (pos, gint, i);
+        indicator->priv->slashPixelPosition[pos_idx++] = get_string_pixel_size (path, g_array_index (pos, gint, i)+1);
+    }
+
+    if (indicator->priv->numPositions>0)
+    {
+        indicator->priv->slashCharPosition[pos_idx] = path_len;
+        indicator->priv->slashPixelPosition[pos_idx] = get_string_pixel_size (path, path_len);
+    }
+
+    g_array_free (pos, TRUE);
 }
 
 
