@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __GNOME_CMD_FILE_PROPS_DIALOG_H__
@@ -22,9 +22,11 @@
 
 #include "gnome-cmd-file.h"
 
+G_BEGIN_DECLS
 
 GtkWidget*
 gnome_cmd_file_props_dialog_create (GnomeCmdFile *finfo);
 
+G_END_DECLS
 
-#endif //__GNOME_CMD_FILE_PROPS_DIALOG_H__
+#endif // __GNOME_CMD_FILE_PROPS_DIALOG_H__
