@@ -1,6 +1,6 @@
 /*
-    GNOME Commander - A GNOME based file manager 
-    Copyright (C) 2001-2004 Marcus Bjurman
+    GNOME Commander - A GNOME based file manager
+    Copyright (C) 2001-2006 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,57 +14,80 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/ 
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
+
 #ifndef __GNOME_CMD_FILE_H__
 #define __GNOME_CMD_FILE_H__
 
+#include <config.h>
+
+
 #define GNOME_CMD_FILE(obj) \
-	GTK_CHECK_CAST (obj, gnome_cmd_file_get_type (), GnomeCmdFile)
+    GTK_CHECK_CAST (obj, gnome_cmd_file_get_type (), GnomeCmdFile)
 #define GNOME_CMD_FILE_CLASS(klass) \
-	GTK_CHECK_CLASS_CAST (klass, gnome_cmd_file_get_type (), GnomeCmdFileClass)
+    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_file_get_type (), GnomeCmdFileClass)
 #define GNOME_CMD_IS_FILE(obj) \
     GTK_CHECK_TYPE (obj, gnome_cmd_file_get_type ())
 
 
-typedef struct _GnomeCmdFile GnomeCmdFile;
-typedef struct _GnomeCmdFileClass GnomeCmdFileClass;
-typedef struct _GnomeCmdFilePrivate	GnomeCmdFilePrivate;
+typedef struct _GnomeCmdFile        GnomeCmdFile;
+typedef struct _GnomeCmdFileClass   GnomeCmdFileClass;
+typedef struct _GnomeCmdFilePrivate GnomeCmdFilePrivate;
+typedef struct _GnomeCmdFileMetadata GnomeCmdFileMetadata;
+
+struct _GnomeCmdFileMetadata
+{
+    gboolean accessed;
+    gpointer metadata;
+};
 
 struct _GnomeCmdFile
 {
-	GnomeCmdFileInfo parent;
+    GnomeCmdFileInfo parent;
 
-	GnomeVFSFileInfo *info;
-	GnomeCmdFilePrivate *priv;
+    GnomeVFSFileInfo *info;
+    GnomeCmdFilePrivate *priv;
+#ifdef HAVE_EXIF
+    GnomeCmdFileMetadata exif;
+#endif
+#ifdef HAVE_IPTC
+    GnomeCmdFileMetadata iptc;
+#endif
+#ifdef HAVE_LCMS
+    GnomeCmdFileMetadata icc;
+#endif
+#ifdef HAVE_ID3
+    GnomeCmdFileMetadata id3;
+#endif
 };
 
 struct _GnomeCmdFileClass
 {
-	GnomeCmdFileInfoClass parent_class;
+    GnomeCmdFileInfoClass parent_class;
 };
 
-
-#include "gnome-cmd-file.h"
 #include "gnome-cmd-dir.h"
 
+G_BEGIN_DECLS
+
 GtkType gnome_cmd_file_get_type (void);
 
 GnomeCmdFile *gnome_cmd_file_new (GnomeVFSFileInfo *info,
-								  GnomeCmdDir *dir);
+                                  GnomeCmdDir *dir);
 void gnome_cmd_file_setup (GnomeCmdFile *finfo,
-						   GnomeVFSFileInfo *info,
-						   GnomeCmdDir *dir);
+                           GnomeVFSFileInfo *info,
+                           GnomeCmdDir *dir);
 
 void gnome_cmd_file_ref (GnomeCmdFile *finfo);
 void gnome_cmd_file_unref (GnomeCmdFile *finfo);
 
 GnomeVFSResult gnome_cmd_file_chmod (GnomeCmdFile *finfo,
-									 GnomeVFSFilePermissions perm);
+                                     GnomeVFSFilePermissions perm);
 GnomeVFSResult gnome_cmd_file_chown (GnomeCmdFile *finfo,
-									 uid_t uid, gid_t gid);
+                                     uid_t uid, gid_t gid);
 GnomeVFSResult gnome_cmd_file_rename (GnomeCmdFile *finfo,
-									  const gchar *new_name);
+                                      const gchar *new_name);
 
 const gchar *gnome_cmd_file_get_name (GnomeCmdFile *finfo);
 gchar *gnome_cmd_file_get_quoted_name (GnomeCmdFile *finfo);
@@ -78,20 +101,20 @@ const gchar *gnome_cmd_file_get_extension (GnomeCmdFile *finfo);
 const gchar *gnome_cmd_file_get_owner (GnomeCmdFile *finfo);
 const gchar *gnome_cmd_file_get_group (GnomeCmdFile *finfo);
 const gchar *gnome_cmd_file_get_adate (GnomeCmdFile *finfo,
-									   gboolean overide_disp_setting);
+                                       gboolean overide_disp_setting);
 const gchar *gnome_cmd_file_get_mdate (GnomeCmdFile *finfo,
-									   gboolean overide_disp_setting);
+                                       gboolean overide_disp_setting);
 const gchar *gnome_cmd_file_get_cdate (GnomeCmdFile *finfo,
-									   gboolean overide_disp_setting);
+                                       gboolean overide_disp_setting);
 const gchar *gnome_cmd_file_get_size (GnomeCmdFile *finfo);
 const gchar *gnome_cmd_file_get_tree_size (GnomeCmdFile *finfo);
 const gchar *gnome_cmd_file_get_perm (GnomeCmdFile *finfo);
 const gchar *gnome_cmd_file_get_mime_type_desc (GnomeCmdFile *finfo);
 const gchar *gnome_cmd_file_get_mime_type (GnomeCmdFile *finfo);
 gboolean gnome_cmd_file_has_mime_type (GnomeCmdFile *finfo,
-									   const gchar *mime_type);
+                                       const gchar *mime_type);
 gboolean gnome_cmd_file_mime_begins_with (GnomeCmdFile *finfo,
-										  const gchar *mime_type_start);
+                                          const gchar *mime_type_start);
 
 const gchar *gnome_cmd_file_get_type_string (GnomeCmdFile *finfo);
 const gchar *gnome_cmd_file_get_type_desc (GnomeCmdFile *finfo);
@@ -101,13 +124,13 @@ GdkBitmap *gnome_cmd_file_get_type_mask (GnomeCmdFile *finfo);
 void gnome_cmd_file_show_properties (GnomeCmdFile *finfo);
 void gnome_cmd_file_show_chown_dialog (GList *files);
 void gnome_cmd_file_show_chmod_dialog (GList *files);
-void gnome_cmd_file_view (GnomeCmdFile *finfo);
+void gnome_cmd_file_view (GnomeCmdFile *finfo, gint internal_viewer);
 void gnome_cmd_file_edit (GnomeCmdFile *finfo);
 void gnome_cmd_file_show_cap_cut (GnomeCmdFile *finfo);
 void gnome_cmd_file_show_cap_copy (GnomeCmdFile *finfo);
 void gnome_cmd_file_show_cap_paste (GnomeCmdFile *finfo);
 
-//FIXME: Theese names sucks when we have a class called GnomeCmdFileList...
+//FIXME: These names suck when we have a class called GnomeCmdFileList...
 GList *gnome_cmd_file_list_copy (GList *files);
 void gnome_cmd_file_list_free (GList *files);
 void gnome_cmd_file_list_ref (GList *files);
@@ -116,8 +139,11 @@ void gnome_cmd_file_list_unref (GList *files);
 void gnome_cmd_file_update_info (GnomeCmdFile *finfo, GnomeVFSFileInfo *info);
 gboolean gnome_cmd_file_is_local (GnomeCmdFile *finfo);
 gboolean gnome_cmd_file_is_executable (GnomeCmdFile *finfo);
+void gnome_cmd_file_is_deleted (GnomeCmdFile *finfo);
 void gnome_cmd_file_execute (GnomeCmdFile *finfo);
 
 gboolean gnome_cmd_file_needs_update (GnomeCmdFile *finfo);
 
-#endif //__GNOME_CMD_FILE_H__
+G_END_DECLS
+
+#endif // __GNOME_CMD_FILE_H__
