@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -106,7 +106,7 @@ create_general_tab (GtkWidget *parent)
     gtk_box_pack_start (GTK_BOX (vbox), cat, FALSE, TRUE, 0);
 
     radio = create_radio (parent, NULL, _("CTRL+ALT+letters"), "ctrl_alt_quick_search");
-	gtk_box_pack_start (GTK_BOX (cat_box), radio, FALSE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (cat_box), radio, FALSE, TRUE, 0);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), !gnome_cmd_data_get_alt_quick_search ());
     radio = create_radio (parent, get_radio_group(radio), _("ALT+letters (menu access with F10)"), "alt_quick_search");
     gtk_container_add (GTK_CONTAINER (cat_box), radio);
@@ -207,6 +207,11 @@ create_format_tab (GtkWidget *parent)
     if (gnome_cmd_data_get_size_disp_mode () == GNOME_CMD_SIZE_DISP_MODE_POWERED)
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
 
+    radio = create_radio (parent, get_radio_group (radio), _("<locale>"), "size_locale_radio");
+    gtk_container_add (GTK_CONTAINER (cat_box), radio);
+    if (gnome_cmd_data_get_size_disp_mode () == GNOME_CMD_SIZE_DISP_MODE_LOCALE)
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
+
     radio = create_radio (parent, get_radio_group (radio), _("Grouped"), "size_grouped_radio");
     gtk_container_add (GTK_CONTAINER (cat_box), radio);
     if (gnome_cmd_data_get_size_disp_mode () == GNOME_CMD_SIZE_DISP_MODE_GROUPED)
@@ -275,6 +280,7 @@ static void
 store_format_options (GnomeCmdOptionsDialog *dialog)
 {
     GtkWidget *size_powered_radio = lookup_widget (GTK_WIDGET (dialog), "size_powered_radio");
+    GtkWidget *size_locale_radio = lookup_widget (GTK_WIDGET (dialog), "size_locale_radio");
     GtkWidget *size_grouped_radio = lookup_widget (GTK_WIDGET (dialog), "size_grouped_radio");
     GtkWidget *perm_text_radio = lookup_widget (GTK_WIDGET (dialog), "perm_text_radio");
     GtkWidget *entry = lookup_widget (GTK_WIDGET (dialog), "date_format_entry");
@@ -282,6 +288,8 @@ store_format_options (GnomeCmdOptionsDialog *dialog)
 
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (size_powered_radio)))
         gnome_cmd_data_set_size_disp_mode (GNOME_CMD_SIZE_DISP_MODE_POWERED);
+    else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (size_locale_radio)))
+        gnome_cmd_data_set_size_disp_mode (GNOME_CMD_SIZE_DISP_MODE_LOCALE);
     else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (size_grouped_radio)))
         gnome_cmd_data_set_size_disp_mode (GNOME_CMD_SIZE_DISP_MODE_GROUPED);
     else
@@ -465,6 +473,7 @@ create_layout_tab (GtkWidget *parent)
         _("Modern"),
         _("Fusion"),
         _("Classic"),
+        _("Deep blue"),
         _("Custom"),
         NULL
     };
@@ -657,17 +666,17 @@ create_confirmation_tab (GtkWidget *parent)
     gtk_box_pack_start (GTK_BOX (vbox), cat, FALSE, TRUE, 0);
 
     radio = create_radio (parent, NULL, _("Silently"), "copy_overwrite_silently");
-	gtk_box_pack_start (GTK_BOX (cat_box), radio, FALSE, TRUE, 0);
-	if (gnome_cmd_data_get_confirm_overwrite_copy()==GNOME_CMD_CONFIRM_OVERWRITE_SILENTLY)
-    	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
+    gtk_box_pack_start (GTK_BOX (cat_box), radio, FALSE, TRUE, 0);
+    if (gnome_cmd_data_get_confirm_overwrite_copy()==GNOME_CMD_CONFIRM_OVERWRITE_SILENTLY)
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
     radio = create_radio (parent, get_radio_group(radio), _("Query first"), "copy_overwrite_query");
     gtk_container_add (GTK_CONTAINER (cat_box), radio);
-	if (gnome_cmd_data_get_confirm_overwrite_copy()==GNOME_CMD_CONFIRM_OVERWRITE_QUERY)
-    	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
+    if (gnome_cmd_data_get_confirm_overwrite_copy()==GNOME_CMD_CONFIRM_OVERWRITE_QUERY)
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
     radio = create_radio (parent, get_radio_group(radio), _("Skip all"), "copy_overwrite_skip_all");
     gtk_container_add (GTK_CONTAINER (cat_box), radio);
-	if (gnome_cmd_data_get_confirm_overwrite_copy()==GNOME_CMD_CONFIRM_OVERWRITE_SKIP_ALL)
-    	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
+    if (gnome_cmd_data_get_confirm_overwrite_copy()==GNOME_CMD_CONFIRM_OVERWRITE_SKIP_ALL)
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
 
 
     /* Move overwrite options
@@ -677,20 +686,20 @@ create_confirmation_tab (GtkWidget *parent)
     gtk_box_pack_start (GTK_BOX (vbox), cat, FALSE, TRUE, 0);
 
     radio = create_radio (parent, NULL, _("Silently"), "move_overwrite_silently");
-	gtk_box_pack_start (GTK_BOX (cat_box), radio, FALSE, TRUE, 0);
-	if (gnome_cmd_data_get_confirm_overwrite_move()==GNOME_CMD_CONFIRM_OVERWRITE_SILENTLY)
-    	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
+    gtk_box_pack_start (GTK_BOX (cat_box), radio, FALSE, TRUE, 0);
+    if (gnome_cmd_data_get_confirm_overwrite_move()==GNOME_CMD_CONFIRM_OVERWRITE_SILENTLY)
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
     radio = create_radio (parent, get_radio_group(radio), _("Query first"), "move_overwrite_query");
     gtk_container_add (GTK_CONTAINER (cat_box), radio);
-	if (gnome_cmd_data_get_confirm_overwrite_move()==GNOME_CMD_CONFIRM_OVERWRITE_QUERY)
-    	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
+    if (gnome_cmd_data_get_confirm_overwrite_move()==GNOME_CMD_CONFIRM_OVERWRITE_QUERY)
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
     radio = create_radio (parent, get_radio_group(radio), _("Skip all"), "move_overwrite_skip_all");
     gtk_container_add (GTK_CONTAINER (cat_box), radio);
-	if (gnome_cmd_data_get_confirm_overwrite_move()==GNOME_CMD_CONFIRM_OVERWRITE_SKIP_ALL)
-    	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
+    if (gnome_cmd_data_get_confirm_overwrite_move()==GNOME_CMD_CONFIRM_OVERWRITE_SKIP_ALL)
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
 
 
-	return frame;
+    return frame;
 }
 
 
@@ -698,12 +707,12 @@ static void
 store_confirmation_options (GnomeCmdOptionsDialog *dialog)
 {
     GtkWidget *confirm_delete_check = lookup_widget (GTK_WIDGET (dialog), "confirm_delete_check");
-	GtkWidget *confirm_copy_silent = lookup_widget (GTK_WIDGET (dialog), "copy_overwrite_silently");
-	GtkWidget *confirm_copy_query = lookup_widget (GTK_WIDGET (dialog), "copy_overwrite_query");
-	GtkWidget *confirm_copy_skip_all = lookup_widget (GTK_WIDGET (dialog), "copy_overwrite_skip_all");
-	GtkWidget *confirm_move_silent = lookup_widget (GTK_WIDGET (dialog), "move_overwrite_silently");
-	GtkWidget *confirm_move_query = lookup_widget (GTK_WIDGET (dialog), "move_overwrite_query");
-	GtkWidget *confirm_move_skip_all = lookup_widget (GTK_WIDGET (dialog), "move_overwrite_skip_all");
+    GtkWidget *confirm_copy_silent = lookup_widget (GTK_WIDGET (dialog), "copy_overwrite_silently");
+    GtkWidget *confirm_copy_query = lookup_widget (GTK_WIDGET (dialog), "copy_overwrite_query");
+    GtkWidget *confirm_copy_skip_all = lookup_widget (GTK_WIDGET (dialog), "copy_overwrite_skip_all");
+    GtkWidget *confirm_move_silent = lookup_widget (GTK_WIDGET (dialog), "move_overwrite_silently");
+    GtkWidget *confirm_move_query = lookup_widget (GTK_WIDGET (dialog), "move_overwrite_query");
+    GtkWidget *confirm_move_skip_all = lookup_widget (GTK_WIDGET (dialog), "move_overwrite_skip_all");
 
     gnome_cmd_data_set_confirm_delete (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (confirm_delete_check)));
 
@@ -1555,7 +1564,7 @@ create_device_dialog (GnomeCmdConDevice *dev, GtkSignalFunc on_ok, GtkSignalFunc
 
     if (dev) s = gnome_cmd_con_device_get_icon_path (dev);
     entry = create_icon_entry (dialog, "device_iconentry", s);
-    icon_dir = g_build_path ("/",PIXMAPS_DIR, "device-icons", NULL);
+    icon_dir = g_build_path (G_DIR_SEPARATOR_S,PIXMAPS_DIR, "device-icons", NULL);
     gnome_icon_entry_set_pixmap_subdir (GNOME_ICON_ENTRY (entry), icon_dir);
     g_free (icon_dir);
     table_add (table, entry, 1, 3, GTK_FILL);
@@ -1600,8 +1609,8 @@ on_device_edit (GtkWidget *button, GtkWidget *parent)
 static void
 on_device_remove (GtkWidget *button, GtkWidget *frame)
 {
-    GnomeCmdConDevice *dev;
     GtkCList *clist = GTK_CLIST (lookup_widget (frame, "device_clist"));
+    GnomeCmdConDevice *dev;
 
     if (clist->focus_row >= 0) {
         dev = GNOME_CMD_CON_DEVICE (gtk_clist_get_row_data (clist, clist->focus_row));
@@ -1616,11 +1625,10 @@ static void
 on_device_selected (GtkCList *clist, gint row, gint column,
                     GdkEventButton *event, GtkWidget *parent)
 {
-    GnomeCmdConDevice *dev;
     GtkWidget *remove_button = lookup_widget (parent, "remove_device_button");
     GtkWidget *edit_button = lookup_widget (parent, "edit_device_button");
 
-    dev = GNOME_CMD_CON_DEVICE (gtk_clist_get_row_data (clist, row));
+    GnomeCmdConDevice *dev = GNOME_CMD_CON_DEVICE (gtk_clist_get_row_data (clist, row));
     gtk_object_set_data (GTK_OBJECT (parent), "selected_device", dev);
 
     gtk_widget_set_sensitive (remove_button, TRUE);
@@ -1733,8 +1741,8 @@ create_devices_tab (GtkWidget *parent)
 
     clist = gtk_object_get_data (GTK_OBJECT (parent), "device_clist");
     for ( devices = gnome_cmd_con_list_get_all_dev (gnome_cmd_data_get_con_list ()); devices; devices = devices->next )
-	    if (!gnome_cmd_con_device_get_autovol(devices->data))
-		add_device_to_list (GTK_CLIST (clist), GNOME_CMD_CON_DEVICE (devices->data));
+        if (!gnome_cmd_con_device_get_autovol(devices->data))
+        add_device_to_list (GTK_CLIST (clist), GNOME_CMD_CON_DEVICE (devices->data));
 
     return frame;
 }
@@ -1799,13 +1807,13 @@ map (GtkWidget *widget)
 
 
 static void
-class_init (GnomeCmdOptionsDialogClass *class)
+class_init (GnomeCmdOptionsDialogClass *klass)
 {
     GtkObjectClass *object_class;
     GtkWidgetClass *widget_class;
 
-    object_class = GTK_OBJECT_CLASS (class);
-    widget_class = GTK_WIDGET_CLASS (class);
+    object_class = GTK_OBJECT_CLASS (klass);
+    widget_class = GTK_WIDGET_CLASS (klass);
 
     parent_class = gtk_type_class (gnome_cmd_dialog_get_type ());
 
