@@ -14,13 +14,16 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
+
 #ifndef __GNOME_CMD_RENAME_DIALOG_H__
 #define __GNOME_CMD_RENAME_DIALOG_H__
 
 #include "gnome-cmd-file.h"
 
+G_BEGIN_DECLS
+
 #define GNOME_CMD_RENAME_DIALOG(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_rename_dialog_get_type (), GnomeCmdRenameDialog)
 #define GNOME_CMD_RENAME_DIALOG_CLASS(klass) \
@@ -37,26 +40,23 @@ typedef struct _GnomeCmdRenameDialogClass GnomeCmdRenameDialogClass;
 
 struct _GnomeCmdRenameDialog
 {
-    GnomeCmdStringDialog parent;
+    GtkWindow parent;
     GnomeCmdRenameDialogPrivate *priv;
 };
 
 
 struct _GnomeCmdRenameDialogClass
 {
-    GnomeCmdStringDialogClass parent_class;
+    GtkWindowClass parent_class;
 };
 
 
 GtkWidget*
-gnome_cmd_rename_dialog_new (GnomeCmdFile *finfo);
+gnome_cmd_rename_dialog_new (GnomeCmdFile *finfo, gint x, gint y, gint width, gint height);
 
 GtkType
 gnome_cmd_rename_dialog_get_type (void);
 
+G_END_DECLS
 
-
-
-#endif //__GNOME_CMD_RENAME_DIALOG_H__
-
-
+#endif // __GNOME_CMD_RENAME_DIALOG_H__
