@@ -1,6 +1,6 @@
 /*
-    GNOME Commander - A GNOME based file manager 
-    Copyright (C) 2001-2003 Marcus Bjurman
+    GNOME Commander - A GNOME based file manager
+    Copyright (C) 2001-2006 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,20 +14,22 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/ 
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
+
 #ifndef __GNOME_CMD_SEARCH_DIALOG_H__
 #define __GNOME_CMD_SEARCH_DIALOG_H__
 
 #include "gnome-cmd-dir.h"
 
+G_BEGIN_DECLS
 
 #define GNOME_CMD_SEARCH_DIALOG(obj) \
-	GTK_CHECK_CAST (obj, gnome_cmd_search_dialog_get_type (), GnomeCmdSearchDialog)
+    GTK_CHECK_CAST (obj, gnome_cmd_search_dialog_get_type (), GnomeCmdSearchDialog)
 #define GNOME_CMD_SEARCH_DIALOG_CLASS(klass) \
-	GTK_CHECK_CLASS_CAST (klass, gnome_cmd_search_dialog_get_type (), GnomeCmdSearchDialogClass)
+    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_search_dialog_get_type (), GnomeCmdSearchDialogClass)
 #define GNOME_CMD_IS_SEARCH_DIALOG(obj) \
-	GTK_CHECK_TYPE (obj, gnome_cmd_search_dialog_get_type ())
+    GTK_CHECK_TYPE (obj, gnome_cmd_search_dialog_get_type ())
 
 
 typedef struct _GnomeCmdSearchDialog GnomeCmdSearchDialog;
@@ -38,15 +40,15 @@ typedef struct _GnomeCmdSearchDialogClass GnomeCmdSearchDialogClass;
 
 struct _GnomeCmdSearchDialog
 {
-	GnomeCmdDialog parent;
+    GnomeCmdDialog parent;
 
-	GnomeCmdSearchDialogPrivate *priv;
+    GnomeCmdSearchDialogPrivate *priv;
 };
 
 
 struct _GnomeCmdSearchDialogClass
 {
-	GnomeCmdDialogClass parent_class;
+    GnomeCmdDialogClass parent_class;
 };
 
 
@@ -56,5 +58,6 @@ gnome_cmd_search_dialog_get_type            (void);
 GtkWidget*
 gnome_cmd_search_dialog_new                 (GnomeCmdDir *default_dir);
 
+G_END_DECLS
 
-#endif //__GNOME_CMD_SEARCH_DIALOG_H__
+#endif // __GNOME_CMD_SEARCH_DIALOG_H__
