@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __LS_COLORS_H__
@@ -22,6 +22,8 @@
 
 #include "gnome-cmd-file.h"
 
+G_BEGIN_DECLS
+
 typedef struct {
     GnomeVFSFileType type;
     gchar *ext;
@@ -31,4 +33,6 @@ typedef struct {
 void     ls_colors_init (void);
 LsColor *ls_colors_get (GnomeCmdFile *finfo);
 
-#endif //__LS_COLORS_H__
+G_END_DECLS
+
+#endif // __LS_COLORS_H__
