@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -107,7 +107,7 @@ main (int argc, char *argv[])
     ls_colors_init ();
     gdk_rgb_init ();
     gnome_vfs_init ();
-    conf_dir = g_build_path ("/", g_get_home_dir(), ".gnome-commander", NULL);
+    conf_dir = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir(), ".gnome-commander", NULL);
     create_dir_if_needed (conf_dir);
     g_free (conf_dir);
     gnome_cmd_data_load ();
