@@ -43,8 +43,7 @@ static GnomeCmdFileList *get_active_fl ()
 {
     GnomeCmdFileSelector *fs = gnome_cmd_main_win_get_active_fs (main_win);
 
-    if (fs) return fs->list;
-    return NULL;
+    return fs ? fs->list : NULL;
 }
 
 
@@ -104,16 +103,13 @@ void
 file_copy                           (GtkMenuItem     *menuitem,
                                      gpointer        not_used)
 {
-    GnomeCmdFileSelector *src_fs;
-    GnomeCmdFileSelector *dest_fs;
+    if (!main_win)  return;
 
-    if (main_win) {
-        src_fs = gnome_cmd_main_win_get_active_fs (main_win);
-        dest_fs = gnome_cmd_main_win_get_inactive_fs (main_win);
+    GnomeCmdFileSelector *src_fs = gnome_cmd_main_win_get_active_fs (main_win);
+    GnomeCmdFileSelector *dest_fs = gnome_cmd_main_win_get_inactive_fs (main_win);
 
-        if (src_fs && dest_fs)
-            gnome_cmd_prepare_copy_dialog_show (src_fs, dest_fs);
-    }
+    if (src_fs && dest_fs)
+        gnome_cmd_prepare_copy_dialog_show (src_fs, dest_fs);
 }
 
 
@@ -121,16 +117,13 @@ void
 file_move                           (GtkMenuItem     *menuitem,
                                      gpointer        not_used)
 {
-    GnomeCmdFileSelector *src_fs;
-    GnomeCmdFileSelector *dest_fs;
+    if (!main_win)  return;
 
-    if (main_win) {
-        src_fs = gnome_cmd_main_win_get_active_fs (main_win);
-        dest_fs = gnome_cmd_main_win_get_inactive_fs (main_win);
+    GnomeCmdFileSelector *src_fs = gnome_cmd_main_win_get_active_fs (main_win);
+    GnomeCmdFileSelector *dest_fs = gnome_cmd_main_win_get_inactive_fs (main_win);
 
-        if (src_fs && dest_fs)
-            gnome_cmd_prepare_move_dialog_show (src_fs, dest_fs);
-    }
+    if (src_fs && dest_fs)
+        gnome_cmd_prepare_move_dialog_show (src_fs, dest_fs);
 }
 
 
@@ -173,7 +166,7 @@ file_edit                           (GtkMenuItem     *menuitem,
     GdkModifierType mask;
 
     gdk_window_get_pointer (NULL, NULL, NULL, &mask);
-    
+
     if (mask & GDK_SHIFT_MASK)
         gnome_cmd_file_selector_start_editor (get_active_fs ());
     else
@@ -209,9 +202,29 @@ void
 file_create_symlink                 (GtkMenuItem     *menuitem,
                                      gpointer        not_used)
 {
-    GnomeCmdFile *finfo = gnome_cmd_file_list_get_focused_file (get_active_fl ());
-    gnome_cmd_file_selector_create_symlink (
-        gnome_cmd_main_win_get_inactive_fs (main_win), finfo);
+    GnomeCmdFileSelector *inactive_fs = gnome_cmd_main_win_get_inactive_fs (main_win);
+    GList *f = gnome_cmd_file_list_get_selected_files (get_active_fl ());
+    guint selected_files = g_list_length (f);
+
+    if (selected_files > 1)
+    {
+        gchar *msg = g_strdup_printf (ngettext("Create symbolic links of %i file in %s?",
+                                               "Create symbolic links of %i files in %s?",
+                                               selected_files),
+                                      selected_files, gnome_cmd_dir_get_display_path (gnome_cmd_file_selector_get_directory(inactive_fs)));
+
+        gint choice = run_simple_dialog (GTK_WIDGET (main_win), TRUE, GTK_MESSAGE_QUESTION, msg, _("Create Symbolic Link"), 1, _("Cancel"), _("Create"), NULL);
+
+        g_free (msg);
+
+        if (choice==1)
+            gnome_cmd_file_selector_create_symlinks (inactive_fs, f);
+    }
+   else
+   {
+        GnomeCmdFile *finfo = gnome_cmd_file_list_get_focused_file (get_active_fl ());
+        gnome_cmd_file_selector_create_symlink (inactive_fs, finfo);
+   }
 }
 
 
@@ -252,7 +265,7 @@ file_diff                           (GtkMenuItem     *menuitem,
         GnomeCmdFile *finfo2 = NULL;
         gboolean found = FALSE;
         GList *all_files = gnome_cmd_file_list_get_all_files (GNOME_CMD_FILE_LIST (gnome_cmd_main_win_get_inactive_fs (main_win)->list));
-        
+
 
         /**
          * Go through all the files in the other list until we find one with the same name
@@ -276,8 +289,7 @@ file_diff                           (GtkMenuItem     *menuitem,
         cmd = g_strdup_printf (gnome_cmd_data_get_differ (), p1, p2?:"");
 
         g_free (p1);
-        if (p2)
-            g_free (p2);
+        g_free (p2);
 
         run_command (cmd, FALSE);
         g_print (_("running \"%s\"\n"), cmd);
@@ -313,9 +325,7 @@ edit_search                         (GtkMenuItem     *menuitem,
                                      gpointer        not_used)
 {
     GnomeCmdFileSelector *fs = get_active_fs ();
-    GtkWidget *dialog =
-        gnome_cmd_search_dialog_new (
-            gnome_cmd_file_selector_get_directory (fs));
+    GtkWidget *dialog = gnome_cmd_search_dialog_new (gnome_cmd_file_selector_get_directory (fs));
     gtk_widget_ref (dialog);
     gtk_widget_show (dialog);
 }
@@ -341,12 +351,12 @@ void
 edit_copy_fnames                    (GtkMenuItem     *menuitem,
                                      gpointer        not_used)
 {
-    GdkModifierType mask;
-
     static gchar sep[] = " ";
 
+    GdkModifierType mask;
+
     gdk_window_get_pointer (NULL, NULL, NULL, &mask);
-    
+
     GnomeCmdFileList *fl = get_active_fl ();
     GList *sfl = gnome_cmd_file_list_get_selected_files (fl);
     GList *i;
@@ -356,7 +366,7 @@ edit_copy_fnames                    (GtkMenuItem     *menuitem,
 
     sfl = gnome_cmd_file_list_sort_selection (sfl, fl);
 
-    for (i = sfl; i; i = i->next) 
+    for (i = sfl; i; i = i->next)
     {
         GnomeCmdFile *finfo = GNOME_CMD_FILE (i->data);
 
@@ -579,7 +589,15 @@ view_refresh                           (GtkMenuItem     *menuitem,
 }
 
 
-/************** Options Menu **************/
+void
+view_equal_panes                       (GtkMenuItem     *menuitem,
+                                         gpointer        not_used)
+{
+    gnome_cmd_main_win_set_equal_panes (GTK_WIDGET (main_win));
+}
+
+
+                                         /************** Options Menu **************/
 void
 options_edit                        (GtkMenuItem     *menuitem,
                                      gpointer        not_used)
@@ -630,15 +648,12 @@ void
 connections_close           (GtkMenuItem     *menuitem,
                              GnomeCmdCon *con)
 {
-    GnomeCmdCon *c1, *c2, *home;
-    GnomeCmdFileSelector *active, *inactive;
+    GnomeCmdFileSelector *active = gnome_cmd_main_win_get_active_fs (main_win);
+    GnomeCmdFileSelector *inactive = gnome_cmd_main_win_get_inactive_fs (main_win);
 
-    active = gnome_cmd_main_win_get_active_fs (main_win);
-    inactive = gnome_cmd_main_win_get_inactive_fs (main_win);
-
-    c1 = gnome_cmd_file_selector_get_connection (active);
-    c2 = gnome_cmd_file_selector_get_connection (inactive);
-    home = gnome_cmd_con_list_get_home (gnome_cmd_data_get_con_list ());
+    GnomeCmdCon *c1 = gnome_cmd_file_selector_get_connection (active);
+    GnomeCmdCon *c2 = gnome_cmd_file_selector_get_connection (inactive);
+    GnomeCmdCon *home = gnome_cmd_con_list_get_home (gnome_cmd_data_get_con_list ());
 
     if (con == c1)
         gnome_cmd_file_selector_set_connection (active, home, NULL);
@@ -735,32 +750,35 @@ void
 help_about                          (GtkMenuItem     *menuitem,
                                      gpointer        not_used)
 {
-    gchar *authors[] = {
+    static const gchar *authors[] = {
         "Marcus Bjurman <marbj499@student.liu.se>",
         "Piotr Eljasiak <epiotr@use.pl>",
         "Assaf Gordon <agordon88@gmail.com>",
         NULL
     };
 
-    gchar *docers[] = {
+    static const gchar *documenters[] = {
         "Marcus Bjurman <marbj499@student.liu.se>",
         "Piotr Eljasiak <epiotr@use.pl>",
         NULL
     };
 
-    GtkWidget *dialog = gnome_about_new (
-        "GNOME Commander",
-        VERSION,
-        "Copyright (C) 2001-2006 Marcus Bjurman",
-        _("A fast and powerful file manager for the GNOME desktop"),
-        (const gchar**)authors,
-        (const gchar**)docers,
-        /* xgettext:
-         * Replace this with your name when translating  */
-        _("No translation is currently in use."),
-        NULL);
+    static const gchar copyright[] = \
+        // "Copyright \xc2\xa9 2001-2006 Marcus Bjurman\n"
+        "Copyright \xc2\xa9 2001-2006 Marcus Bjurman";
 
-    gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
-    gtk_widget_ref (dialog);
-    gtk_widget_show (dialog);
+    static const gchar comments[] = \
+        N_("A fast and powerful file manager for the GNOME desktop");
+
+    gtk_show_about_dialog (GTK_WINDOW (main_win),
+                   "authors", authors,
+                   "comments", _(comments),
+                   "copyright", copyright,
+                   "documenters", documenters,
+                   "translator-credits", _("translator-credits"),
+                   "version", VERSION,
+                   "website", "http://www.nongnu.org/gcmd",
+                   "name", "GNOME Commander",
+                   "logo-icon-name", PACKAGE_NAME,
+                   NULL);
 }
