@@ -14,13 +14,15 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
+
 #ifndef __USERACTIONS_H__
 #define __USERACTIONS_H__
 
 #include "gnome-cmd-main-win.h"
 
+G_BEGIN_DECLS
 
 /************** File Menu **************/
 void
@@ -239,6 +241,10 @@ void
 view_refresh                           (GtkMenuItem     *menuitem,
                                          gpointer        not_used);
 
+void
+view_equal_panes                       (GtkMenuItem     *menuitem,
+                                         gpointer        not_used);
+
 
 /************** Bookmarks Menu **************/
 void
@@ -294,9 +300,22 @@ void
 help_help                           (GtkMenuItem     *menuitem,
                                      gpointer        not_used);
 
+void
+help_keyboard                       (GtkMenuItem     *menuitem,
+                                     gpointer        not_used);
+
+void
+help_web                            (GtkMenuItem     *menuitem,
+                                     gpointer        not_used);
+
+void
+help_problem                        (GtkMenuItem     *menuitem,
+                                     gpointer        not_used);
+
 void
 help_about                          (GtkMenuItem     *menuitem,
                                      gpointer        not_used);
 
+G_END_DECLS
 
-#endif //__USERACTIONS_H__
+#endif // __USERACTIONS_H__
