@@ -27,6 +27,9 @@
 
 G_BEGIN_DECLS
 
+#define TRACE(x,fmt)         printf("TRACE  " #x ": " #fmt "\n", x)
+#define ARRAY_ELEMENTS(a)   (sizeof(a)/sizeof(a[0]))
+
 gboolean DEBUG_ENABLED (gchar flag);
 void DEBUG (gchar flag, const gchar *fmt, ...);
 void warn_print (const gchar *fmt, ...);
@@ -40,7 +43,6 @@ gint run_simple_dialog (GtkWidget *parent, gboolean ignore_close_box,
                         const char *text, const char *title, gint def_response, ...);
 
 
-
 gboolean string2int (const gchar *s, gint *i);
 gboolean string2uint (const gchar *s, guint *i);
 gboolean string2short (const gchar *s, gshort *sh);
